@@ -1,11 +1,9 @@
 module RSpec
   module Matchers
     module BuiltIn
-      class Equal
-        include BaseMatcher
-
-        def matches?(actual)
-          super(actual).equal?(expected)
+      class Equal < BaseMatcher
+        def match(expected, actual)
+          actual.equal? expected
         end
 
         def failure_message_for_should
@@ -16,7 +14,7 @@ expected #{inspect_object(expected)}
 
 Compared using equal?, which compares object identity,
 but expected and actual are not the same object. Use
-'actual.should == expected' if you don't care about
+`#{eq_expression}` if you don't care about
 object identity in this example.
 
 MESSAGE
@@ -33,15 +31,17 @@ Compared using equal?, which compares object identity.
 MESSAGE
         end
 
-        def diffable?
-          true
-        end
+        def diffable?; true; end
 
-      private
+        private
 
         def inspect_object(o)
           "#<#{o.class}:#{o.object_id}> => #{o.inspect}"
         end
+
+        def eq_expression
+          Expectations::Syntax.positive_expression("actual", "eq(expected)")
+        end
       end
     end
   end
