@@ -11,8 +11,17 @@ module RSpec
           registry[klass][operator] = matcher
         end
 
+        def unregister(klass, operator)
+          registry[klass] && registry[klass].delete(operator)
+        end
+
         def get(klass, operator)
-          registry[klass] && registry[klass][operator]
+          klass.ancestors.each { |ancestor|
+            matcher = registry[ancestor] && registry[ancestor][operator]
+            return matcher if matcher
+          }
+
+          nil
         end
       end
 
@@ -22,8 +31,8 @@ module RSpec
 
       def self.use_custom_matcher_or_delegate(operator)
         define_method(operator) do |expected|
-          if matcher = OperatorMatcher.get(@actual.class, operator)
-            @actual.send(::RSpec::Matchers.last_should, matcher.new(expected))
+          if uses_generic_implementation_of?(operator) && matcher = OperatorMatcher.get(@actual.class, operator)
+            @actual.__send__(::RSpec::Matchers.last_should, matcher.new(expected))
           else
             eval_match(@actual, operator, expected)
           end
@@ -53,6 +62,22 @@ module RSpec
 
       private
 
+      if Method.method_defined?(:owner) # 1.8.6 lacks Method#owner :-(
+        def uses_generic_implementation_of?(op)
+          @actual.method(op).owner == ::Kernel
+        end
+      else
+        def uses_generic_implementation_of?(op)
+          # This is a bit of a hack, but:
+          #
+          # {}.method(:=~).to_s # => "#<Method: Hash(Kernel)#=~>"
+          #
+          # In the absence of Method#owner, this is the best we
+          # can do to see if the method comes from Kernel.
+          @actual.method(op).to_s.include?('(Kernel)')
+        end
+      end
+
       def eval_match(actual, operator, expected)
         ::RSpec::Matchers.last_matcher = self
         @operator, @expected = operator, expected
@@ -66,7 +91,7 @@ module RSpec
           if actual.__send__(operator, expected)
             true
           elsif ['==','===', '=~'].include?(operator)
-            fail_with_message("expected: #{expected.inspect}\n     got: #{actual.inspect} (using #{operator})") 
+            fail_with_message("expected: #{expected.inspect}\n     got: #{actual.inspect} (using #{operator})")
           else
             fail_with_message("expected: #{operator} #{expected.inspect}\n     got: #{operator.gsub(/./, ' ')} #{actual.inspect}")
           end
