@@ -6,7 +6,7 @@ class SomethingExpected
   attr_accessor :some_value
 end
 
-describe "should change(actual, message)" do
+describe "expect { ... }.to change(actual, message)" do
   context "with a numeric value" do
     before(:each) do
       @instance = SomethingExpected.new
@@ -22,12 +22,26 @@ describe "should change(actual, message)" do
         expect {}.to change(@instance, :some_value)
       end.to fail_with("some_value should have changed, but is still 5")
     end
-    
+
     it "provides a #description" do
-      change(@instance, :some_value).description.should == "change #some_value"
+      expect(change(@instance, :some_value).description).to eq "change #some_value"
     end
   end
 
+  it "can specify the change of a variable's class" do
+    val = nil
+
+    expect {
+      val = 42
+    }.to change { val.class }.from(NilClass).to(Fixnum)
+
+    expect {
+      expect {
+        val = "string"
+      }.to change { val.class }.from(Fixnum).to(NilClass)
+    }.to fail_with(/but is now String/)
+  end
+
   context "with boolean values" do
     before(:each) do
       @instance = SomethingExpected.new
@@ -72,6 +86,17 @@ describe "should change(actual, message)" do
       expect {@instance.some_value << 1}.to change(@instance, :some_value)
     end
 
+    it "fails when a predicate on the actual fails" do
+      expect do
+        expect {@instance.some_value << 1}.to change { @instance.some_value }.to be_empty
+      end.to fail_with(/result should have been changed to/)
+    end
+
+    it "passes when a predicate on the actual passes" do
+      @instance.some_value = [1]
+      expect {@instance.some_value.pop}.to change { @instance.some_value }.to be_empty
+    end
+
     it "fails when actual is not modified by the block" do
       expect do
         expect {}.to change(@instance, :some_value)
@@ -96,6 +121,20 @@ describe "should change(actual, message)" do
     end
   end
 
+  context "with a string" do
+    it "passes when actual is modified by the block" do
+      string = "ab"
+      expect { string << "c" }.to change { string }
+    end
+
+    it 'fails when actual is not modified by the block' do
+      string = "ab"
+      expect {
+        expect { }.to change { string }
+      }.to fail_with(/should have changed/)
+    end
+  end
+
   context "with an arbitrary enumerable" do
     before(:each) do
       @instance = SomethingExpected.new
@@ -135,24 +174,30 @@ describe "should change(actual, message)" do
   end
 end
 
-describe "should_not change(actual, message)" do
+describe "expect { ... }.not_to change(actual, message)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
   end
 
   it "passes when actual is not modified by the block" do
-    expect { }.to_not change(@instance, :some_value)
+    expect { }.not_to change(@instance, :some_value)
   end
 
   it "fails when actual is not modified by the block" do
     expect do
-      expect {@instance.some_value = 6}.to_not change(@instance, :some_value)
+      expect {@instance.some_value = 6}.not_to change(@instance, :some_value)
     end.to fail_with("some_value should not have changed, but did change from 5 to 6")
   end
 end
 
-describe "should change { block }" do
+describe "expect { ... }.to change { block }" do
+  o = SomethingExpected.new
+  it_behaves_like "an RSpec matcher", :valid_value => lambda { o.some_value = 5 },
+                                      :invalid_value => lambda { } do
+    let(:matcher) { change { o.some_value } }
+  end
+
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
@@ -167,42 +212,42 @@ describe "should change { block }" do
       expect {}.to change{ @instance.some_value }
     end.to fail_with("result should have changed, but is still 5")
   end
-  
+
   it "warns if passed a block using do/end instead of {}" do
     expect do
       expect {}.to change do; end
     end.to raise_error(SyntaxError, /block passed to should or should_not/)
   end
-  
+
   it "provides a #description" do
-    change { @instance.some_value }.description.should == "change #result"
+    expect(change { @instance.some_value }.description).to eq "change #result"
   end
 end
 
-describe "should_not change { block }" do
+describe "expect { ... }.not_to change { block }" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
   end
 
   it "passes when actual is modified by the block" do
-    expect {}.to_not change{ @instance.some_value }
+    expect {}.not_to change{ @instance.some_value }
   end
 
   it "fails when actual is not modified by the block" do
     expect do
-      expect {@instance.some_value = 6}.to_not change { @instance.some_value }
+      expect {@instance.some_value = 6}.not_to change { @instance.some_value }
     end.to fail_with("result should not have changed, but did change from 5 to 6")
   end
-  
+
   it "warns if passed a block using do/end instead of {}" do
     expect do
-      expect {}.to_not change do; end
+      expect {}.not_to change do; end
     end.to raise_error(SyntaxError, /block passed to should or should_not/)
   end
 end
 
-describe "should change(actual, message).by(expected)" do
+describe "expect { ... }.to change(actual, message).by(expected)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
@@ -229,7 +274,7 @@ describe "should change(actual, message).by(expected)" do
   end
 end
 
-describe "should change{ block }.by(expected)" do
+describe "expect { ... }.to change { block }.by(expected)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
@@ -252,7 +297,7 @@ describe "should change{ block }.by(expected)" do
   end
 end
 
-describe "should change(actual, message).by_at_least(expected)" do
+describe "expect { ... }.to change(actual, message).by_at_least(expected)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
@@ -261,10 +306,10 @@ describe "should change(actual, message).by_at_least(expected)" do
   it "passes when attribute is changed by greater than the expected amount" do
     expect { @instance.some_value += 2 }.to change(@instance, :some_value).by_at_least(1)
   end
-  
+
   it "passes when attribute is changed by the expected amount" do
     expect { @instance.some_value += 2 }.to change(@instance, :some_value).by_at_least(2)
-  end  
+  end
 
   it "fails when the attribute is changed by less than the expected amount" do
     expect do
@@ -274,7 +319,7 @@ describe "should change(actual, message).by_at_least(expected)" do
 
 end
 
-describe "should change{ block }.by_at_least(expected)" do
+describe "expect { ... }.to change { block }.by_at_least(expected)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
@@ -283,10 +328,10 @@ describe "should change{ block }.by_at_least(expected)" do
   it "passes when attribute is changed by greater than expected amount" do
     expect { @instance.some_value += 2 }.to change{@instance.some_value}.by_at_least(1)
   end
-  
+
   it "passes when attribute is changed by the expected amount" do
     expect { @instance.some_value += 2 }.to change{@instance.some_value}.by_at_least(2)
-  end  
+  end
 
   it "fails when the attribute is changed by less than the unexpected amount" do
     expect do
@@ -296,7 +341,7 @@ describe "should change{ block }.by_at_least(expected)" do
 end
 
 
-describe "should change(actual, message).by_at_most(expected)" do
+describe "expect { ... }.to change(actual, message).by_at_most(expected)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
@@ -305,10 +350,10 @@ describe "should change(actual, message).by_at_most(expected)" do
   it "passes when attribute is changed by less than the expected amount" do
     expect { @instance.some_value += 2 }.to change(@instance, :some_value).by_at_most(3)
   end
-  
+
   it "passes when attribute is changed by the expected amount" do
     expect { @instance.some_value += 2 }.to change(@instance, :some_value).by_at_most(2)
-  end  
+  end
 
   it "fails when the attribute is changed by greater than the expected amount" do
     expect do
@@ -318,7 +363,7 @@ describe "should change(actual, message).by_at_most(expected)" do
 
 end
 
-describe "should change{ block }.by_at_most(expected)" do
+describe "expect { ... }.to change { block }.by_at_most(expected)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 5
@@ -327,10 +372,10 @@ describe "should change{ block }.by_at_most(expected)" do
   it "passes when attribute is changed by less than expected amount" do
     expect { @instance.some_value += 2 }.to change{@instance.some_value}.by_at_most(3)
   end
-  
+
   it "passes when attribute is changed by the expected amount" do
     expect { @instance.some_value += 2 }.to change{@instance.some_value}.by_at_most(2)
-  end  
+  end
 
   it "fails when the attribute is changed by greater than the unexpected amount" do
     expect do
@@ -339,7 +384,7 @@ describe "should change{ block }.by_at_most(expected)" do
   end
 end
 
-describe "should change(actual, message).from(old)" do
+describe "expect { ... }.to change(actual, message).from(old)" do
   context "with boolean values" do
     before(:each) do
       @instance = SomethingExpected.new
@@ -380,7 +425,7 @@ describe "should change(actual, message).from(old)" do
   end
 end
 
-describe "should change{ block }.from(old)" do
+describe "expect { ... }.to change { block }.from(old)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 'string'
@@ -403,13 +448,13 @@ describe "should change{ block }.from(old)" do
   end
 end
 
-describe "should change(actual, message).to(new)" do
+describe "expect { ... }.to change(actual, message).to(new)" do
   context "with boolean values" do
     before(:each) do
       @instance = SomethingExpected.new
       @instance.some_value = true
     end
-    
+
     it "passes when attribute is == to expected value after executing block" do
       expect { @instance.some_value = false }.to change(@instance, :some_value).to(false)
     end
@@ -425,7 +470,7 @@ describe "should change(actual, message).to(new)" do
       @instance = SomethingExpected.new
       @instance.some_value = 'string'
     end
-    
+
     it "passes when attribute is === to expected value after executing block" do
       expect { @instance.some_value = "cat" }.to change(@instance, :some_value).to("cat")
     end
@@ -444,12 +489,12 @@ describe "should change(actual, message).to(new)" do
   end
 end
 
-describe "should change{ block }.to(new)" do
+describe "expect { ... }.to change { block }.to(new)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 'string'
   end
-  
+
   it "passes when attribute is === to expected value after executing block" do
     expect { @instance.some_value = "cat" }.to change{@instance.some_value}.to("cat")
   end
@@ -467,12 +512,12 @@ describe "should change{ block }.to(new)" do
   end
 end
 
-describe "should change(actual, message).from(old).to(new)" do
+describe "expect { ... }.to change(actual, message).from(old).to(new)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 'string'
   end
-  
+
   it "passes when #to comes before #from" do
     expect { @instance.some_value = "cat" }.to change(@instance, :some_value).to("cat").from("string")
   end
@@ -480,13 +525,13 @@ describe "should change(actual, message).from(old).to(new)" do
   it "passes when #from comes before #to" do
     expect { @instance.some_value = "cat" }.to change(@instance, :some_value).from("string").to("cat")
   end
-  
+
   it "shows the correct messaging when #after and #to are different" do
     expect do
       expect { @instance.some_value = "cat" }.to change(@instance, :some_value).from("string").to("dog")
     end.to fail_with("some_value should have been changed to \"dog\", but is now \"cat\"")
   end
-  
+
   it "shows the correct messaging when #before and #from are different" do
     expect do
       expect { @instance.some_value = "cat" }.to change(@instance, :some_value).from("not_string").to("cat")
@@ -494,12 +539,12 @@ describe "should change(actual, message).from(old).to(new)" do
   end
 end
 
-describe "should change{ block }.from(old).to(new)" do
+describe "expect { ... }.to change { block }.from(old).to(new)" do
   before(:each) do
     @instance = SomethingExpected.new
     @instance.some_value = 'string'
   end
-  
+
   it "passes when #to comes before #from" do
     expect { @instance.some_value = "cat" }.to change{@instance.some_value}.to("cat").from("string")
   end
@@ -514,9 +559,9 @@ describe RSpec::Matchers::BuiltIn::Change do
     @instance = SomethingExpected.new
     @instance.some_value = "string"
     def @instance.send(*args); raise "DOH! Library developers shouldn't use #send!" end
-    
+
     expect {
       expect { @instance.some_value = "cat" }.to change(@instance, :some_value)
-    }.to_not raise_error
+    }.not_to raise_error
   end
 end
