@@ -2,48 +2,69 @@ require 'spec_helper'
 module RSpec
   module Matchers
     describe "equal" do
-      
+      it_behaves_like "an RSpec matcher", :valid_value => :a, :invalid_value => :b do
+        let(:matcher) { equal(:a) }
+      end
+
       def inspect_object(o)
         "#<#{o.class}:#{o.object_id}> => #{o.inspect}"
       end
-      
+
       it "matches when actual.equal?(expected)" do
-        1.should equal(1)
+        expect(1).to equal(1)
       end
 
       it "does not match when !actual.equal?(expected)" do
-        "1".should_not equal("1")
+        expect("1").not_to equal("1")
       end
-      
+
       it "describes itself" do
         matcher = equal(1)
         matcher.matches?(1)
-        matcher.description.should == "equal 1"
+        expect(matcher.description).to eq "equal 1"
       end
-      
-      it "provides message on #failure_message" do
+
+      it "suggests the `eq` matcher on failure" do
         expected, actual = "1", "1"
-        matcher = equal(expected)
-        matcher.matches?(actual)
-        
-        matcher.failure_message_for_should.should == <<-MESSAGE
+        expect {
+          expect(actual).to equal(expected)
+        }.to fail_with <<-MESSAGE
 
 expected #{inspect_object(expected)}
      got #{inspect_object(actual)}
 
 Compared using equal?, which compares object identity,
 but expected and actual are not the same object. Use
-'actual.should == expected' if you don't care about
+`expect(actual).to eq(expected)` if you don't care about
 object identity in this example.
 
 MESSAGE
       end
-      
+
+      context "when using only `should`", :uses_only_should do
+        it "suggests the `eq` matcher on failure" do
+          expected, actual = "1", "1"
+          lambda {
+            actual.should equal(expected)
+          }.should fail_with <<-MESSAGE
+
+expected #{inspect_object(expected)}
+     got #{inspect_object(actual)}
+
+Compared using equal?, which compares object identity,
+but expected and actual are not the same object. Use
+`actual.should eq(expected)` if you don't care about
+object identity in this example.
+
+MESSAGE
+        end
+      end
+
       it "provides message on #negative_failure_message" do
         expected = actual = "1"
         matcher = equal(expected)
         matcher.matches?(actual)
-        matcher.failure_message_for_should_not.should == <<-MESSAGE
+        expect(matcher.failure_message_for_should_not).to eq <<-MESSAGE
 
 expected not #{inspect_object(expected)}
          got #{inspect_object(actual)}
